@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,9 +11,9 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings, flag_text
-from ..operations import eventsops
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings, flag_text
+from ebcli.operations import eventsops
 
 
 class EventsController(AbstractBaseController):
@@ -31,4 +31,4 @@ class EventsController(AbstractBaseController):
         env_name = self.get_env_name()
         follow = self.app.pargs.follow
 
-        eventsops.print_events(app_name, env_name, follow)
\ No newline at end of file
+        eventsops.print_events(app_name, env_name, follow)
