@@ -1,4 +1,4 @@
-# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,21 +10,48 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-from ebcli.core.ebglobals import Constants
 from ebcli.core import fileoperations, io
 from ebcli.core.abstractcontroller import AbstractBaseController
-from ebcli.operations import platformops
+from ebcli.operations import platformops, platform_version_ops
 from ebcli.resources.strings import strings, flag_text, prompts
 
 
 class GenericPlatformDeleteController(AbstractBaseController):
     class Meta:
+        is_platform_workspace_only_command = True
+        requires_directory_initialization = True
         description = strings['platformdeleteversion.info']
         arguments = [
-            (['version'], dict(action='store', help=flag_text['platformdeleteversion.version'], nargs='?', default=None)),
-            (['--cleanup'], dict(action='store_true', help=flag_text['platformdelete.cleanup'])),
-            (['--all-platforms'], dict(action='store_true', help=flag_text['platformdelete.allplatforms'])),
-            (['--force'], dict(action='store_true', help=flag_text['platformdelete.force']))
+            (
+                ['version'],
+                dict(
+                    action='store',
+                    help=flag_text['platformdeleteversion.version'],
+                    nargs='?',
+                    default=None
+                )
+            ),
+            (
+                ['--cleanup'],
+                dict(
+                    action='store_true',
+                    help=flag_text['platformdelete.cleanup']
+                )
+            ),
+            (
+                ['--all-platforms'],
+                dict(
+                    action='store_true',
+                    help=flag_text['platformdelete.allplatforms']
+                )
+            ),
+            (
+                ['--force'],
+                dict(
+                    action='store_true',
+                    help=flag_text['platformdelete.force']
+                )
+            )
         ]
         epilog = strings['platformdeleteversion.epilog']
 
@@ -41,7 +68,7 @@ class GenericPlatformDeleteController(AbstractBaseController):
             self.cleanup_platforms()
         else:
             if version:
-                platformops.delete_platform_version(version, force)
+                platform_version_ops.delete_platform_version(version, force)
             else:
                 self.app.args.print_help()
 
@@ -54,9 +81,8 @@ class GenericPlatformDeleteController(AbstractBaseController):
         else:
             platform_name = fileoperations.get_platform_name()
 
-        # We clean up all failed platform versions
         failed_versions = sorted(
-            platformops.list_custom_platform_versions(
+            platform_version_ops.list_custom_platform_versions(
                 platform_name=platform_name,
                 status='Failed',
             )
@@ -76,7 +102,7 @@ class GenericPlatformDeleteController(AbstractBaseController):
                     io.validate_action(prompts['cleanupplatform.validate'], platform_name)
 
             for failed_version in failed_versions:
-	            platformops.delete_platform_version(failed_version, force=True)
+                platform_version_ops.delete_platform_version(failed_version, force=True)
 
 
 class PlatformDeleteController(GenericPlatformDeleteController):
