@@ -1,28 +1,48 @@
-import os, sys
+# Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License"). You
+# may not use this file except in compliance with the License. A copy of
+# the License is located at
+#
+# http://aws.amazon.com/apache2.0/
+#
+# or in the "license" file accompanying this file. This file is
+# distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
+# ANY KIND, either express or implied. See the License for the specific
+# language governing permissions and limitations under the License.
+import os
+import sys
 
 import logging
 import traceback
 
-from argparse import SUPPRESS, ArgumentTypeError
+from argparse import ArgumentTypeError
 
 from botocore.compat import six
 
 from ebcli.lib.aws import TooManyPlatformsError
 
-iteritems = six.iteritems
-
 from cement.core.exc import CaughtSignal
 
-from . import io
-from ebcli.objects.exceptions import *
+from ebcli.core import io
+from ebcli.objects.exceptions import (
+    ConnectionError,
+    NoEnvironmentForBranchError,
+    InvalidStateError,
+    NotInitializedError,
+    NoSourceControlError,
+    NoRegionError,
+    EBCLIException
+)
 from ebcli.resources.strings import strings
 
+iteritems = six.iteritems
+
 
 def fix_path():
     parent_folder = os.path.dirname(__file__)
     parent_dir = os.path.abspath(parent_folder)
     while not parent_folder.endswith('ebcli'):
-        # Keep going up until we get to the right folder
         parent_folder = os.path.dirname(parent_folder)
         parent_dir = os.path.abspath(parent_folder)
 
@@ -30,6 +50,7 @@ def fix_path():
 
     sys.path.insert(0, vendor_dir)
 
+
 fix_path()
 
 
@@ -39,13 +60,12 @@ def run_app(app):
     try:
         app.setup()
         app.run()
-
-    # Handle General Exceptions
+        app.close()
     except CaughtSignal:
         io.echo()
         app.close(code=5)
     except NoEnvironmentForBranchError:
-        pass
+        app.close(code=5)
     except InvalidStateError:
         io.log_error(strings['exit.invalidstate'])
         app.close(code=3)
@@ -71,12 +91,10 @@ def run_app(app):
         if '--verbose' in sys.argv or '--debug' in sys.argv:
             io.log_info(traceback.format_exc())
         else:
-            io.log_error(e.__class__.__name__ + " - " + e.message)
+            io.log_error('{0} - {1}'.format(e.__class__.__name__, e.message))
 
         app.close(code=4)
     except Exception as e:
-        # Generic catch all
-
         if str(e):
             message = '{exception_class} - {message}'.format(
                 exception_class=e.__class__.__name__,
@@ -92,8 +110,8 @@ def run_app(app):
             io.log_info(message)
         else:
             io.log_error(message)
-    finally:
-        app.close()
+
+        app.close(code=4)
 
 
 def squash_cement_logging():
