@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -14,11 +14,11 @@
 import os
 import re
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings
-from ..objects.exceptions import NotFoundError
-from ..core import io, fileoperations
-from ..lib import elasticbeanstalk, s3, heuristics, cloudformation, utils
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings
+from ebcli.objects.exceptions import NotFoundError
+from ebcli.core import io, fileoperations
+from ebcli.lib import elasticbeanstalk, s3, heuristics, cloudformation, utils
 
 
 class DownloadController(AbstractBaseController):
@@ -40,7 +40,9 @@ def download_source_bundle(app_name, env_name):
     env = elasticbeanstalk.get_environment(app_name=app_name, env_name=env_name)
     if env.version_label and env.version_label != 'Sample Application':
         app_version = elasticbeanstalk.get_application_versions(
-        app_name, version_labels=[env.version_label])['ApplicationVersions'][0]
+            app_name,
+            version_labels=[env.version_label]
+        )['ApplicationVersions'][0]
 
         source_bundle = app_version['SourceBundle']
         bucket_name = source_bundle['S3Bucket']
@@ -49,7 +51,6 @@ def download_source_bundle(app_name, env_name):
         data = s3.get_object(bucket_name, key_name)
         filename = get_filename(key_name)
     else:
-        # sample app
         template = cloudformation.get_template('awseb-' + env.id + '-stack')
         try:
             url = template['TemplateBody']['Parameters']['AppSource']['Default']
@@ -68,16 +69,16 @@ def download_source_bundle(app_name, env_name):
 
     cwd = os.getcwd()
     try:
-        fileoperations._traverse_to_project_root()
+        fileoperations.ProjectRoot.traverse()
         if heuristics.directory_is_empty():
-            # If we dont have any project code, unzip as current project
             io.echo('Unzipping application version as project files.')
             fileoperations.unzip_folder(location, os.getcwd())
             io.echo('Done.')
     finally:
         os.chdir(cwd)
 
+
 def get_filename(url):
     pattern = re.compile('^(?:.*[/])*([^/]+)$')
     matcher = re.match(pattern, url)
-    return matcher.group(1).strip()
\ No newline at end of file
+    return matcher.group(1).strip()
