@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -12,10 +12,10 @@
 # language governing permissions and limitations under the License.
 
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings
-from ..core import io
-from ..lib import elasticbeanstalk, aws
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings
+from ebcli.core import io
+from ebcli.lib import elasticbeanstalk, aws
 from botocore.compat import six
 urllib = six.moves.urllib
 
@@ -48,16 +48,11 @@ def get_quick_link(app_name, env_name):
         option_settings, 'aws:autoscaling:launchconfiguration', 'InstanceType')
 
     link = 'https://console.aws.amazon.com/elasticbeanstalk/home?'
-    # add region
     region = aws.get_region_name()
     link += 'region=' + urllib.parse.quote(region)
-    # add quicklaunch flag
     link += '#/newApplication'
-    # add application name
     link += '?applicationName=' + urllib.parse.quote(app_name)
-    # add solution stack
     link += '&solutionStackName=' + urllib.parse.quote(env.platform.platform_shorthand)
-    # add
     link += '&tierName=' + env.tier.name
     if environment_type:
         link += '&environmentType=' + environment_type
@@ -109,4 +104,4 @@ def _add_vpc_options(link, option_settings):
         option_settings, 'aws:ec2:vpc', 'VPCId')
     if vpc_id:
         link += '&withVpc=true'
-    return link
\ No newline at end of file
+    return link
