@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,10 +10,9 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-
-from ..lib import utils, elasticbeanstalk, aws
-from ..objects.exceptions import NotSupportedError
-from . import commonops
+from ebcli.lib import utils, elasticbeanstalk, aws
+from ebcli.objects.exceptions import NotSupportedError
+from ebcli.operations import commonops
 
 
 def open_console(app_name, env_name):
@@ -21,7 +20,6 @@ def open_console(app_name, env_name):
         raise NotSupportedError('The console command is not supported'
                                 ' in an ssh type session')
 
-    #Get environment id
     env = None
     if env_name is not None:
         env = elasticbeanstalk.get_environment(app_name=app_name, env_name=env_name)
@@ -32,7 +30,6 @@ def open_console(app_name, env_name):
     else:
         page = 'application/overview'
 
-    #encode app name
     app_name = utils.url_encode(app_name)
 
     console_url = 'console.aws.amazon.com/elasticbeanstalk/home?'
@@ -42,4 +39,4 @@ def open_console(app_name, env_name):
     if env is not None:
         console_url += '&environmentId=' + env.id
 
-    commonops.open_webpage_in_browser(console_url, ssl=True)
\ No newline at end of file
+    commonops.open_webpage_in_browser(console_url, ssl=True)
