@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -12,10 +12,10 @@
 # language governing permissions and limitations under the License.
 from cement.utils.misc import minimal_logger
 
-from . import commonops
-from ..core import io, fileoperations
-from ..lib import elasticbeanstalk, aws
-from ..operations import gitops, buildspecops
+from ebcli.operations import commonops
+from ebcli.core import io, fileoperations
+from ebcli.lib import elasticbeanstalk, aws
+from ebcli.operations import gitops, buildspecops
 
 LOG = minimal_logger(__name__)
 
@@ -24,7 +24,6 @@ def deploy(app_name, env_name, version, label, message, group_name=None,
            process_app_versions=False, staged=False, timeout=5, source=None):
     region_name = aws.get_region_name()
 
-    # Parse and get Build Configuration from BuildSpec if it exists
     build_config = None
     if fileoperations.build_spec_exists() and version is None:
         build_config = fileoperations.get_build_configuration()
@@ -36,7 +35,13 @@ def deploy(app_name, env_name, version, label, message, group_name=None,
         app_version_label = version
     elif source is not None:
         app_version_label = commonops.create_app_version_from_source(
-            app_name, source, process=process_app_versions, label=label, message=message, build_config=build_config)
+            app_name,
+            source,
+            process=process_app_versions,
+            label=label,
+            message=message,
+            build_config=build_config
+        )
         io.echo("Starting environment deployment via specified source")
         process_app_versions = True
     elif gitops.git_management_enabled() and not staged:
@@ -45,19 +50,27 @@ def deploy(app_name, env_name, version, label, message, group_name=None,
         io.echo("Starting environment deployment via CodeCommit")
         process_app_versions = True
     else:
-        # Create app version
         app_version_label = commonops.create_app_version(
-            app_name, process=process_app_versions, label=label, message=message, staged=staged, build_config=build_config)
+            app_name,
+            process=process_app_versions,
+            label=label,
+            message=message,
+            staged=staged,
+            build_config=build_config
+        )
 
     if build_config is not None:
-        buildspecops.stream_build_configuration_app_version_creation(app_name, app_version_label, build_config)
+        buildspecops.stream_build_configuration_app_version_creation(
+            app_name, app_version_label, build_config)
     elif process_app_versions is True:
-        success = commonops.wait_for_processed_app_versions(app_name,
-                                                            [app_version_label])
+        success = commonops.wait_for_processed_app_versions(
+            app_name,
+            [app_version_label],
+            timeout=timeout or 5
+        )
         if not success:
             return
 
-    # swap env to new app version
     request_id = elasticbeanstalk.update_env_application_version(
         env_name, app_version_label, group_name)
 
@@ -65,22 +78,3 @@ def deploy(app_name, env_name, version, label, message, group_name=None,
                                       timeout_in_minutes=timeout,
                                       can_abort=True,
                                       env_name=env_name)
-
-
-def deploy_no_events(app_name, env_name, version, label, message, process=False, staged=False):
-    region_name = aws.get_region_name()
-
-    io.log_info('Deploying code to ' + env_name + ' in region ' + region_name)
-
-    if version:
-        app_version_label = version
-    else:
-        # Create app version
-        app_version_label = commonops.create_app_version(
-            app_name, process=process, label=label, message=message, staged=staged)
-
-    # swap env to new app version
-    request_id = elasticbeanstalk.update_env_application_version(
-        env_name, app_version_label)
-
-    return request_id
